@@ -20,11 +20,11 @@ def get_pairwise_performance_gap(
 
     fgr, fgr1, fgr2 = (unwrap(x.results.fine_grained) for x in (sys, sys1, sys2))
     for bucket_attr, buckets in fgr.items():
-        for bucket_name, bucket in buckets.items():
+        for bucket_id, bucket in enumerate(buckets):
             for perf_id, perf in enumerate(bucket.performances):
                 perf.value = float(
-                    fgr1[bucket_attr][bucket_name].performances[perf_id].value
-                ) - float(fgr2[bucket_attr][bucket_name].performances[perf_id].value)
+                    fgr1[bucket_attr][bucket_id].performances[perf_id].value
+                ) - float(fgr2[bucket_attr][bucket_id].performances[perf_id].value)
                 # TODO(gneubig): these could be done via pairwise bootstraps
                 perf.confidence_score_low = None
                 perf.confidence_score_high = None
