@@ -13,6 +13,8 @@ from explainaboard.processors import (
     named_entity_recognition,
     qa_multiple_choice,
     summarization,
+    tabular_classification,
+    tabular_regression,
     text_classification,
     text_pair_classification,
     word_segmentation,
@@ -31,6 +33,8 @@ __all__ = [
     'qa_multiple_choice',
     'summarization',
     'text_classification',
+    'tabular_classification',
+    'tabular_regression',
     'text_pair_classification',
     'word_segmentation',
     'chunking',
